Stan Math Library: stan::math::sum_eigen_v_vari Class Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Member Functions | Static Protected Member Functions | List of all members
stan::math::sum_eigen_v_vari Class Reference

Class for representing sums with constructors for Eigen. More...

`#include <sum.hpp>`

Inheritance diagram for stan::math::sum_eigen_v_vari:

## Public Member Functions
template<int R1, int C1>
| sum_eigen_v_vari (const Eigen::Matrix< var, R1, C1 > &v1)
Public Member Functions inherited from stan::math::sum_v_vari
| sum_v_vari (double value, vari **v, size_t length)
| sum_v_vari (const std::vector< var > &v1)
virtual void | chain ()
| Apply the chain rule to this variable based on the variables on which it depends. More...
Public Member Functions inherited from stan::math::vari
| vari (const double x)
| Construct a variable implementation from a value. More...
| vari (const double x, bool stacked)
virtual | ~vari ()
| Throw an illegal argument exception. More...
void | init_dependent ()
| Initialize the adjoint for this (dependent) variable to 1. More...
void | set_zero_adjoint ()
| Set the adjoint value of this variable to 0. More...

## Static Protected Member Functions
template<typename Derived >
static double | sum_of_val (const Eigen::DenseBase< Derived > &v)
Static Protected Member Functions inherited from stan::math::sum_v_vari
static double | sum_of_val (const std::vector< var > &v)

## Additional Inherited Members
Static Public Member Functions inherited from stan::math::vari
static void * | operator new (size_t nbytes)
| Allocate memory from the underlying memory pool. More...
static void | operator delete (void *)
| Delete a pointer from the underlying memory pool. More...
Public Attributes inherited from stan::math::vari
const double | val_
| The value of this variable. More...
double | adj_
| The adjoint of this variable, which is the partial derivative of this variable with respect to the root variable. More...
Protected Attributes inherited from stan::math::sum_v_vari
vari ** | v_
size_t | length_

## Detailed Description

Class for representing sums with constructors for Eigen.

The `chain()` method and member variables are managed by the superclass `sum_v_vari`.

Definition at line 17 of file sum.hpp.

## Constructor & Destructor Documentation

template<int R1, int C1>

stan::math::sum_eigen_v_vari::sum_eigen_v_vari | ( | const Eigen::Matrix< var, R1, C1 > & | v1 | ) |
| inlineexplicit

Definition at line 29 of file sum.hpp.

## Member Function Documentation

template<typename Derived >

static double stan::math::sum_eigen_v_vari::sum_of_val | ( | const Eigen::DenseBase< Derived > & | v | ) |
| inlinestaticprotected

Definition at line 20 of file sum.hpp.

The documentation for this class was generated from the following file:

- stan/math/rev/mat/fun/sum.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.